@@ -19,6 +19,7 @@ struct {
   int printdelay=0;
   bool printcfg=1;
   char savedir[256]="\0";
+  char datadir[256]="\0";
 } options;
 */
 
@@ -39,6 +40,7 @@ void DEF_videoandsound ()
     diff += CHOICE_windowwidth -> value (DEF_WINDOW_WIDTH);
     diff += CHOICE_windowheight -> value (DEF_WINDOW_HEIGHT);
     diff += CHECKBUTTON_rotate -> value(0);
+    diff += CHECKBUTTON_screensaver -> value(0);
 
     // Sound Defaults
    
@@ -131,6 +133,8 @@ void DEF_simplification ()
     diff += CHECKBUTTON_disablestampstool	-> value (0);
     diff += CHECKBUTTON_disablestampcontrols -> value (0);
 
+    diff += SLIDER_stampsize -> value(-1);
+
     if (diff)
       activate_buttons();
 }
@@ -267,6 +271,24 @@ void DEF_saving ()
       activate_buttons();
 }
 
+
+void DEF_data ()
+{
+    int diff = 0;
+
+    // Data Directory Defaults
+
+    diff += CHECKBUTTON_nolockfile -> value(0);
+
+    diff += CHECKBUTTON_usealternatedatadir -> value (0);
+    FILEINPUT_alternatedatadir->value("");
+    FILEINPUT_alternatedatadir -> deactivate ();
+    BUTTON_browsealternatedatadir -> deactivate ();
+
+    if (diff)
+      activate_buttons();
+}
+
 bool RNDBUT_askoverwrite_isdef()
 {
     if (ROUNDBUTTON_askbeforeoverwriting->value() == 1)
@@ -284,6 +306,15 @@ bool CHKBUT_altsavedir_isdef()
 }
 
 
+bool CHKBUT_altdatadir_isdef()
+{
+    if (CHECKBUTTON_usealternatedatadir->value() == 0)
+       return 1;
+    else
+       return 0;
+}
+
+
 void CB_SetActualTabToDefaults ()
 {
     if ( TABE_videoandsound	-> visible () )
@@ -321,6 +352,12 @@ void CB_SetActualTabToDefaults ()
         DEF_saving		();
         return;
     }
+    
+    if ( TABE_data -> visible () )
+    {
+        DEF_data		();
+        return;
+    }
 }
 
 void CB_SetAllTabsToDefaults ()
@@ -331,4 +368,5 @@ void CB_SetAllTabsToDefaults ()
     DEF_locale();
     DEF_printing();
     DEF_saving();
+    DEF_data();
 }
